@@ -6,7 +6,7 @@ use 5.008001;
 use Carp qw( croak );
 
 # ABSTRACT: Write Perl bindings to non-Perl libraries with FFI. No XS required.
-our $VERSION = '0.41'; # VERSION
+our $VERSION = '0.42'; # VERSION
 
 # Platypus Man,
 # Platypus Man,
@@ -530,7 +530,7 @@ sub _have_pm
 
 package FFI::Platypus::Function;
 
-our $VERSION = '0.41'; # VERSION
+our $VERSION = '0.42'; # VERSION
 
 use overload '&{}' => sub {
   my $ffi = shift;
@@ -551,7 +551,7 @@ use overload '&{}' => sub {
   sub { $self->{code}->(@_) };
 };
 
-our $VERSION = '0.41'; # VERSION
+our $VERSION = '0.42'; # VERSION
 
 sub new
 {
@@ -580,13 +580,13 @@ sub get_data
 
 package FFI::Platypus::ClosureData;
 
-our $VERSION = '0.41'; # VERSION
+our $VERSION = '0.42'; # VERSION
 
 package FFI::Platypus::Type;
 
 use Carp qw( croak );
 
-our $VERSION = '0.41'; # VERSION
+our $VERSION = '0.42'; # VERSION
 
 sub new
 {
@@ -680,7 +680,7 @@ FFI::Platypus - Write Perl bindings to non-Perl libraries with FFI. No XS requir
 
 =head1 VERSION
 
-version 0.41
+version 0.42
 
 =head1 SYNOPSIS
 
@@ -779,7 +779,7 @@ L<FFI::Platypus::Declare>.
 Platypus has extensive documentation of types at L<FFI::Platypus::Type> 
 and its custom types API at L<FFI::Platypus::API>.
 
-=for stopwords ØMQ
+=for stopwords ÃMQ
 
 =head1 CONSTRUCTORS
 
@@ -1506,7 +1506,7 @@ just-in-time (JIT) compilation service for FFI.
    print "recv_message = $recv_message\n";
  };
 
-B<Discussion>: ØMQ is a high-performance asynchronous messaging library.  
+B<Discussion>: ÃMQ is a high-performance asynchronous messaging library.  
 There are a few things to note here.
 
 Firstly, sometimes there may be multiple versions of a library in the 
@@ -1531,7 +1531,7 @@ the same, it is useful form of documentation that helps describe the
 functionality of the interface.
 
 Finally we attach the necessary functions, send and receive a message. 
-If you are interested, there is a fully fleshed out ØMQ Perl interface 
+If you are interested, there is a fully fleshed out ÃMQ Perl interface 
 implemented using FFI called L<ZMQ::FFI>.
 
 =head2 libarchive
