@@ -5,12 +5,12 @@ use warnings;
 use Config;
 
 # ABSTRACT: Documentation and tools for using Platypus with the Windows API
-our $VERSION = '0.41'; # VERSION
+our $VERSION = '0.42'; # VERSION
 
 
 sub abi
 {
-  $^O =~ /^(cygwin|MSWin32)$/ && $Config{ptrsize} == 4
+  $^O =~ /^(cygwin|MSWin32|msys)$/ && $Config{ptrsize} == 4
   ? 'stdcall'
   : 'default_abi';
 }
@@ -187,7 +187,7 @@ FFI::Platypus::Lang::Win32 - Documentation and tools for using Platypus with the
 
 =head1 VERSION
 
-version 0.41
+version 0.42
 
 =head1 SYNOPSIS
 
