@@ -12,7 +12,7 @@ use Config;
 use base qw( Module::Build );
 
 # ABSTRACT: Build Perl extensions in C with FFI
-our $VERSION = '0.41'; # VERSION
+our $VERSION = '0.42'; # VERSION
 
 
 __PACKAGE__->add_property( ffi_libtest_dir =>
@@ -200,7 +200,7 @@ sub ffi_dlext
 
 sub _ffi_libtest_name ()
 {
-  $^O eq 'cygwin' ? 'cygtest-1' : 'libtest';
+  $^O eq 'cygwin' ? 'cygtest-1' : $^O eq 'msys' ? 'msys-test-1' : 'libtest';
 }
 
 sub ACTION_libtest
@@ -303,7 +303,7 @@ Module::Build::FFI - Build Perl extensions in C with FFI
 
 =head1 VERSION
 
-version 0.41
+version 0.42
 
 =head1 SYNOPSIS
 
